@@ -21,19 +21,26 @@ class TestMCPServer:
     @pytest.mark.asyncio
     async def test_scan_directory_success(self):
         """Test successful directory scan."""
-        with patch("mcp_semclone.server._run_tool") as mock_run:
-            # Mock osslili output (first call)
-            mock_run.return_value = MagicMock(
-                returncode=0,
-                stdout='{"scan_results": []}'
-            )
+        # Mock purl2notices JSON output
+        purl2notices_output = {
+            "metadata": {"total_packages": 0},
+            "licenses": []
+        }
 
-            with patch("pathlib.Path.exists", return_value=True):
-                result = await server_module.scan_directory(
-                    "/test",
-                    check_licenses=False,
-                    check_vulnerabilities=False
-                )
+        with patch("mcp_semclone.server._run_tool") as mock_run, \
+             patch("json.load", return_value=purl2notices_output), \
+             patch("os.path.exists", return_value=True), \
+             patch("os.unlink"), \
+             patch("tempfile.NamedTemporaryFile"), \
+             patch("pathlib.Path.exists", return_value=True):
+
+            mock_run.return_value = MagicMock(returncode=0, stdout="")
+
+            result = await server_module.scan_directory(
+                "/test",
+                check_licenses=False,
+                check_vulnerabilities=False
+            )
 
             assert "licenses" in result
             assert "metadata" in result
@@ -50,15 +57,34 @@ class TestMCPServer:
     @pytest.mark.asyncio
     async def test_scan_directory_with_licenses(self):
         """Test directory scan with license detection."""
-        with patch("mcp_semclone.server._run_tool") as mock_run:
-            # Mock osslili output with license evidence
-            mock_run.return_value = MagicMock(
-                returncode=0,
-                stdout='{"scan_results": [{"license_evidence": [{"detected_license": "MIT", "file": "/test/LICENSE", "confidence": 0.99, "category": "declared"}]}]}'
-            )
+        # Mock purl2notices JSON output with MIT license
+        purl2notices_output = {
+            "metadata": {"total_packages": 1},
+            "licenses": [
+                {
+                    "id": "MIT",
+                    "packages": [
+                        {
+                            "name": "test-pkg",
+                            "version": "1.0.0",
+                            "purl": "pkg:npm/test-pkg@1.0.0"
+                        }
+                    ],
+                    "copyrights": ["Copyright Test Author"]
+                }
+            ]
+        }
 
-            with patch("pathlib.Path.exists", return_value=True):
-                result = await server_module.scan_directory("/test", check_vulnerabilities=False)
+        with patch("mcp_semclone.server._run_tool") as mock_run, \
+             patch("json.load", return_value=purl2notices_output), \
+             patch("os.path.exists", return_value=True), \
+             patch("os.unlink"), \
+             patch("tempfile.NamedTemporaryFile"), \
+             patch("pathlib.Path.exists", return_value=True):
+
+            mock_run.return_value = MagicMock(returncode=0, stdout="")
+
+            result = await server_module.scan_directory("/test", check_vulnerabilities=False)
 
             assert "licenses" in result
             assert len(result["licenses"]) == 1
@@ -67,15 +93,34 @@ class TestMCPServer:
     @pytest.mark.asyncio
     async def test_scan_directory_with_vulnerabilities(self):
         """Test directory scan with vulnerability checking."""
-        with patch("mcp_semclone.server._run_tool") as mock_run:
-            # Mock osslili output only (vulnerabilities require separate package analysis)
-            mock_run.return_value = MagicMock(
-                returncode=0,
-                stdout='{"scan_results": []}'
-            )
+        # Mock purl2notices JSON output with packages for vulnerability checking
+        purl2notices_output = {
+            "metadata": {"total_packages": 2},
+            "licenses": [
+                {
+                    "id": "Apache-2.0",
+                    "packages": [
+                        {
+                            "name": "vuln-test-pkg",
+                            "version": "2.5.0",
+                            "purl": "pkg:npm/vuln-test-pkg@2.5.0"
+                        }
+                    ],
+                    "copyrights": ["Copyright Apache Foundation"]
+                }
+            ]
+        }
 
-            with patch("pathlib.Path.exists", return_value=True):
-                result = await server_module.scan_directory("/test", check_licenses=False)
+        with patch("mcp_semclone.server._run_tool") as mock_run, \
+             patch("json.load", return_value=purl2notices_output), \
+             patch("os.path.exists", return_value=True), \
+             patch("os.unlink"), \
+             patch("tempfile.NamedTemporaryFile"), \
+             patch("pathlib.Path.exists", return_value=True):
+
+            mock_run.return_value = MagicMock(returncode=0, stdout="")
+
+            result = await server_module.scan_directory("/test", check_licenses=False)
 
             assert "licenses" in result
             assert "metadata" in result
@@ -166,19 +211,20 @@ class TestMCPServer:
 
     @pytest.mark.asyncio
     async def test_generate_sbom(self):
-        """Test SBOM generation."""
+        """Test SBOM generation (CycloneDX format)."""
         with patch("mcp_semclone.server.scan_directory") as mock_scan:
             mock_scan.return_value = {
-                "packages": [{"purl": "pkg:npm/express@4.17.1", "name": "express"}],
+                "packages": [{"purl": "pkg:npm/express@4.17.1", "name": "express", "version": "4.17.1"}],
                 "licenses": [{"spdx_id": "MIT", "file": "LICENSE"}]
             }
 
-            result = await server_module.generate_sbom(path="/test", output_format="spdx")
+            result = await server_module.generate_sbom(path="/test")
 
             assert "sbom" in result
-            assert result["sbom"]["spdxVersion"] == "SPDX-2.3"
-            assert result["sbom"]["dataLicense"] == "CC0-1.0"
-            assert len(result["sbom"]["packages"]) == 1
+            assert result["sbom"]["bomFormat"] == "CycloneDX"
+            assert result["sbom"]["specVersion"] == "1.4"
+            assert len(result["sbom"]["components"]) == 1
+            assert result["sbom"]["components"][0]["name"] == "express"
 
     @pytest.mark.asyncio
     async def test_generate_sbom_with_output_file(self, tmp_path):
@@ -477,4 +523,207 @@ class TestRunTool:
             mock_run.side_effect = FileNotFoundError("command not found")
 
             with pytest.raises(FileNotFoundError):
-                _run_tool("nonexistent_tool", ["--help"])
\ No newline at end of file
+                _run_tool("nonexistent_tool", ["--help"])
+
+class TestDownloadAndScanPackage:
+    """Test cases for download_and_scan_package tool."""
+
+    @pytest.mark.asyncio
+    async def test_purl2notices_success(self):
+        """Test successful analysis using purl2notices (primary method)."""
+        # Mock purl2notices cache output
+        cache_data = {
+            "components": [{
+                "name": "express",
+                "version": "4.21.2",
+                "purl": "pkg:npm/express@4.21.2",
+                "licenses": [
+                    {"license": {"id": "MIT"}},
+                    {"license": {"id": "MIT-or-later"}}
+                ],
+                "properties": [
+                    {"name": "copyright", "value": "Copyright 2009-2013 TJ Holowaychuk"},
+                    {"name": "copyright", "value": "Copyright 2014-2015 Douglas Christopher Wilson"}
+                ]
+            }]
+        }
+
+        with patch("mcp_semclone.server._run_tool") as mock_run, \
+             patch("builtins.open", create=True) as mock_open, \
+             patch("pathlib.Path.unlink"):
+            
+            # Mock purl2notices execution
+            mock_run.return_value = MagicMock(returncode=0, stdout="success")
+            
+            # Mock cache file read
+            mock_open.return_value.__enter__.return_value.read.return_value = json.dumps(cache_data)
+
+            result = await server_module.download_and_scan_package(
+                purl="pkg:npm/express@4.21.2"
+            )
+
+            # Verify method used
+            assert result["method_used"] == "purl2notices"
+            assert result["purl"] == "pkg:npm/express@4.21.2"
+            
+            # Verify data extracted
+            assert result["metadata"]["name"] == "express"
+            assert result["metadata"]["version"] == "4.21.2"
+            assert "MIT" in result["detected_licenses"]
+            assert len(result["copyright_statements"]) == 2
+            assert "purl2notices" in result["methods_attempted"]
+
+    @pytest.mark.asyncio
+    async def test_deep_scan_fallback(self):
+        """Test deep scan fallback when purl2notices fails."""
+        # Mock purl2src output
+        purl2src_data = [{
+            "purl": "pkg:npm/express@4.21.2",
+            "download_url": "https://registry.npmjs.org/express/-/express-4.21.2.tgz",
+            "validated": True
+        }]
+
+        # Mock osslili output
+        osslili_data = {
+            "components": [{
+                "licenses": [{"license": {"id": "MIT"}}],
+                "properties": [
+                    {"name": "copyright", "value": "Copyright Test"}
+                ]
+            }]
+        }
+
+        # Mock upmex output
+        upmex_data = {
+            "name": "express",
+            "version": "4.21.2",
+            "license": "MIT"
+        }
+
+        with patch("mcp_semclone.server._run_tool") as mock_run, \
+             patch("urllib.request.urlretrieve") as mock_download, \
+             patch("tempfile.mkdtemp", return_value="/tmp/test"), \
+             patch("pathlib.Path.exists", return_value=True), \
+             patch("shutil.rmtree"):
+
+            def run_tool_side_effect(tool_name, args, *a, **kw):
+                if tool_name == "purl2notices":
+                    # purl2notices fails
+                    return MagicMock(returncode=1, stdout="", stderr="failed")
+                elif tool_name == "purl2src":
+                    return MagicMock(returncode=0, stdout=json.dumps(purl2src_data))
+                elif tool_name == "osslili":
+                    return MagicMock(returncode=0, stdout=json.dumps(osslili_data))
+                elif tool_name == "upmex":
+                    return MagicMock(returncode=0, stdout=json.dumps(upmex_data))
+                return MagicMock(returncode=1, stdout="")
+
+            mock_run.side_effect = run_tool_side_effect
+
+            result = await server_module.download_and_scan_package(
+                purl="pkg:npm/express@4.21.2"
+            )
+
+            # Verify deep scan was used
+            assert result["method_used"] == "deep_scan"
+            assert "purl2notices" in result["methods_attempted"]
+            assert "deep_scan" in result["methods_attempted"]
+            
+            # Verify download was called
+            mock_download.assert_called_once()
+            
+            # Verify data extracted
+            assert "MIT" in result["detected_licenses"]
+            assert len(result["copyright_statements"]) >= 1
+
+    @pytest.mark.asyncio
+    async def test_online_fallback(self):
+        """Test online fallback when deep scan fails."""
+        # Mock upmex online output
+        upmex_data = {
+            "name": "express",
+            "version": "4.21.2",
+            "license": "MIT"
+        }
+
+        with patch("mcp_semclone.server._run_tool") as mock_run, \
+             patch("builtins.open", create=True), \
+             patch("pathlib.Path.unlink"):
+
+            def run_tool_side_effect(tool_name, args, *a, **kw):
+                if tool_name == "purl2notices":
+                    # purl2notices fails
+                    return MagicMock(returncode=1, stdout="", stderr="failed")
+                elif tool_name == "purl2src":
+                    # purl2src fails (no download URL)
+                    return MagicMock(returncode=1, stdout="[]")
+                elif tool_name == "upmex" and "--api" in args:
+                    # Online API succeeds
+                    return MagicMock(returncode=0, stdout=json.dumps(upmex_data))
+                return MagicMock(returncode=1, stdout="")
+
+            mock_run.side_effect = run_tool_side_effect
+
+            result = await server_module.download_and_scan_package(
+                purl="pkg:pypi/somepackage@1.0.0"
+            )
+
+            # Verify online fallback was used
+            assert result["method_used"] == "online_fallback"
+            assert "purl2notices" in result["methods_attempted"]
+            assert "deep_scan" in result["methods_attempted"]
+            assert "online_fallback" in result["methods_attempted"]
+            
+            # Verify metadata extracted
+            assert result["metadata"]["license"] == "MIT"
+
+    @pytest.mark.asyncio
+    async def test_all_methods_fail(self):
+        """Test behavior when all methods fail."""
+        with patch("mcp_semclone.server._run_tool") as mock_run, \
+             patch("builtins.open", create=True), \
+             patch("pathlib.Path.unlink"):
+
+            # All tools fail
+            mock_run.return_value = MagicMock(returncode=1, stdout="", stderr="failed")
+
+            result = await server_module.download_and_scan_package(
+                purl="pkg:npm/invalid@0.0.0"
+            )
+
+            # Verify error state
+            assert result["method_used"] is None
+            assert result["error"] == "All methods failed to retrieve package data"
+            assert len(result["methods_attempted"]) == 3
+            assert "purl2notices" in result["methods_attempted"]
+            assert "deep_scan" in result["methods_attempted"]
+            assert "online_fallback" in result["methods_attempted"]
+
+    @pytest.mark.asyncio
+    async def test_keep_download(self):
+        """Test that keep_download preserves downloaded files."""
+        cache_data = {
+            "components": [{
+                "name": "express",
+                "version": "4.21.2",
+                "purl": "pkg:npm/express@4.21.2",
+                "licenses": [{"license": {"id": "MIT"}}],
+                "properties": []
+            }]
+        }
+
+        with patch("mcp_semclone.server._run_tool") as mock_run, \
+             patch("builtins.open", create=True) as mock_open, \
+             patch("pathlib.Path.unlink"), \
+             patch("shutil.rmtree") as mock_rmtree:
+            
+            mock_run.return_value = MagicMock(returncode=0, stdout="success")
+            mock_open.return_value.__enter__.return_value.read.return_value = json.dumps(cache_data)
+
+            result = await server_module.download_and_scan_package(
+                purl="pkg:npm/express@4.21.2",
+                keep_download=True
+            )
+
+            # Verify cleanup was NOT called (keep_download=True)
+            mock_rmtree.assert_not_called()
